"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadPoolKeysAsync = exports.convertPubkey = exports.convertNumber = exports.convertKeypair = void 0;
const bs58_1 = __importDefault(require("bs58"));
const web3_js_1 = require("@solana/web3.js");
const RaydiumSwap_1 = require("../server/RaydiumSwap");
const convertKeypair = (privateKeyBS58) => {
    return web3_js_1.Keypair.fromSecretKey(Uint8Array.from(bs58_1.default.decode(privateKeyBS58)));
};
exports.convertKeypair = convertKeypair;
const convertNumber = (number) => {
    if (isNaN(Number(number))) {
        throw new Error("Invalid number");
    }
    return Number(number);
};
exports.convertNumber = convertNumber;
const convertPubkey = (publicKey) => {
    return new web3_js_1.PublicKey(publicKey);
};
exports.convertPubkey = convertPubkey;
function loadPoolKeysAsync(devnet) {
    return __awaiter(this, void 0, void 0, function* () {
        const liquidityFile = devnet ? 'https://api.npoint.io/27219e835edec33b2fd8' : 'https://api.raydium.io/v2/sdk/liquidity/mainnet.json';
        const poolKeys = yield (0, RaydiumSwap_1.loadPoolKeys)(liquidityFile);
        if (!poolKeys || poolKeys.length === 0) {
            throw new Error('Pool keys not loaded');
        }
        return poolKeys;
    });
}
exports.loadPoolKeysAsync = loadPoolKeysAsync;
;
