import {
  Connection,
  PublicKey,
  Keypair,
  Transaction,
  SystemProgram,
} from "@solana/web3.js";
import { BN } from "@coral-xyz/anchor";

const SOL_DECIMALS = 9;

export type TransferSolsParams = {
  from: Keypair;
  to: PublicKey;
  sols: number;
};

export const solToLamports = (amountSol: number): BN => {
  return new BN(amountSol.toFixed(SOL_DECIMALS).replace(".", ""));
};

export const lamportsToSol = (lamports: BN): number => {
  return tokenBalanceToNumber(lamports, SOL_DECIMALS);
};

export function tokenBalanceToNumber(bn: BN, decimals: number): number {
  return Number(withDecimalPoint(bn, decimals));
}

export function withDecimalPoint(bn: BN, decimals: number): string {
  const s = bn.toString().padStart(decimals + 1, "0");
  const l = s.length;
  return s.slice(0, l - decimals) + "." + s.slice(-decimals);
}

export const transferSols = async ({
  connection,
  params,
}: {
  connection: Connection;
  params: TransferSolsParams;
}) => {
  // convert SOls to lamports
  const { from, to, sols } = params;

  const lamports = solToLamports(sols);
  const transaction = new Transaction().add(
    SystemProgram.transfer({
      fromPubkey: from.publicKey,
      toPubkey: to,
      lamports,
    })
  );

  const txId = await connection.sendTransaction(transaction, [from]);
  return txId;
};
